import gtk

# menu and toolbar
UI = '''<ui>
  <menubar name="MainMenu">
    <menu action="FileMenu">
      <menuitem action="Open"/>
      <menuitem action="Close"/>
      <separator/>
      <menuitem action="Quit"/>
    </menu>
  </menubar>    
  <toolbar name="MainToolbar">
    <placeholder name="placeholder1">
      <toolitem action="Open" />
      <toolitem action="Close" />    
	  <separator/>
	  <toolitem action="Quit" />
    </placeholder>
  </toolbar>  
</ui>'''

        
class App():
    def __init__(self):        
        # get main layout from file
        builder = gtk.Builder()
        builder.add_from_file("app.xml")
        
        # get widgets
        self.window = builder.get_object ("window")
        self.vbox_main = builder.get_object ("vbox_main")
        
        # connect signal
        self.window.connect ("delete_event",self.on_delete_event)
        
        # set title and position of window
        self.window.set_title ("UIManager sample")
        self.window.set_position(1)
        
        # create menubar and toolbar
        self.create_menubar_toolbar()        
        
        # show all widgets
        self.window.show_all()
    
    def create_menubar_toolbar (self):
        # create IUManager instance
        self.uimanager = gtk.UIManager()

        # add a UI description
        self.uimanager.add_ui_from_string (UI)
        
        # add a UI description from file
        ###self.uimanager.add_ui_from_file ("definition.ui")
        
        # add the accelerator group to the window
        self.accelgroup = self.uimanager.get_accel_group()
        self.window.add_accel_group (self.accelgroup)

        # create actiongroup
        self.actiongroup_window = gtk.ActionGroup ('Window Actions')        

        # add the actiongroup to the uimanager
        self.uimanager.insert_action_group (self.actiongroup_window,0)

        # create actions
        self.actiongroup_window.add_actions([
            ('FileMenu', None, '_File'),
            ('Open', gtk.STOCK_OPEN, '_Open', None, 'Open description', self.on_action_function),
            ('Close', gtk.STOCK_CLOSE, '_Close', None, 'Close description', self.on_action_function),
            ('Quit', gtk.STOCK_QUIT, '_Quit', None, 'Quit the program', self.on_action_quit),
            ('New', gtk.STOCK_NEW, '_New', None, 'New element', self.on_action_function),
        ])
        
        # create a MenuBar
        self.menubar = self.uimanager.get_widget ('/MainMenu')
        self.vbox_main.pack_start (self.menubar,False,False,0)
        
        # create a Toolbar
        self.toolbar = self.uimanager.get_widget ('/MainToolbar')
        #self.toolbar.set_style(gtk.TOOLBAR_ICONS)
        self.toolbar.set_style(gtk.TOOLBAR_BOTH)
        self.vbox_main.pack_start (self.toolbar,False,False,0)

    def on_action_function(self,action):
        print action
                
    def on_delete_event (self,widget, event, user_data=None):
        gtk.main_quit()
        
    def on_action_quit(self,action):
        gtk.main_quit()
        
    def main(self):
        gtk.main()        
    
if __name__ == "__main__":
    app = App()
    app.main()
